# pwm-generator

|   |   |   |
| --- | --- | --- |
| [![image](https://github.com/kamangir/bluer-designs/blob/main/pwm-generator/wiring.png?raw=true)](https://github.com/kamangir/bluer-designs/blob/main/pwm-generator/wiring.svg) | [![image](https://github.com/kamangir/assets2/raw/main/pwm-generator/20251116_124854.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/pwm-generator/20251116_124854.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/raw/main/pwm-generator/20251116_125104.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/pwm-generator/20251116_125104.jpg?raw=true) |
| [![image](https://github.com/kamangir/assets2/raw/main/pwm-generator/20251116_125112.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/pwm-generator/20251116_125112.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/raw/main/pwm-generator/20251116_125132.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/pwm-generator/20251116_125132.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/raw/main/pwm-generator/20251116_125140.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/pwm-generator/20251116_125140.jpg?raw=true) |
| [![image](https://github.com/kamangir/assets2/raw/main/pwm-generator/20251116_125146.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/pwm-generator/20251116_125146.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/raw/main/pwm-generator/20251116_125200.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/pwm-generator/20251116_125200.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/raw/main/pwm-generator/20251116_125206.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/pwm-generator/20251116_125206.jpg?raw=true) |
| [![image](https://github.com/kamangir/assets2/raw/main/pwm-generator/20251116_125212.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/pwm-generator/20251116_125212.jpg?raw=true) |  |  |

## parts

|   |   |   |   |   |   |
| --- | --- | --- | --- | --- | --- |
| [`DC power jack, 5.5 mm`](./parts/dc-power-jack.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/charger-socket.jpg?raw=true)](./parts/dc-power-jack.md)  | [`DC power plug, 5.5 mm`](./parts/dc-power-plug.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/charging-port.jpg?raw=true)](./parts/dc-power-plug.md)  | [`DSN-VC288, panel mount, 4-30 VDC, 10A (50A with shunt resistor), voltmeter ammeter`](./parts/dsn-vc288.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/dsn-vc288.jpg?raw=true)](./parts/dsn-vc288.md)  | [`nuts, bolts, and spacers`](./parts/nuts-bolts-spacers.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/nuts-bolts-spacers.jpg?raw=true)](./parts/nuts-bolts-spacers.md) M3: (4 x bolt + 4 x nut + 4 x 40 mm spacer) | [`plexiglass, 2 mm or 2.5 mm thickness`](./parts/plexiglass.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/plexiglass.jpg?raw=true)](./parts/plexiglass.md) 2 x 80 cm x 100 cm | [`pwm manual DC motor controller, 12 V, ≥ 5 A`](./parts/pwm-manual-dc-motor-controller.md) [![image](https://github.com/kamangir/assets2/raw/main/bluer-sbc/parts/pwm-manual-dc-motor-controller.jpg?raw=true)](./parts/pwm-manual-dc-motor-controller.md)  |

1. [DC power jack, 5.5 mm](./parts/dc-power-jack.md).
1. [DC power plug, 5.5 mm](./parts/dc-power-plug.md).
1. [DSN-VC288, panel mount, 4-30 VDC, 10A (50A with shunt resistor), voltmeter ammeter](./parts/dsn-vc288.md).
1. [nuts, bolts, and spacers](./parts/nuts-bolts-spacers.md): M3: (4 x bolt + 4 x nut + 4 x 40 mm spacer).
1. [plexiglass, 2 mm or 2.5 mm thickness](./parts/plexiglass.md): 2 x 80 cm x 100 cm.
1. [pwm manual DC motor controller, 12 V, ≥ 5 A](./parts/pwm-manual-dc-motor-controller.md).
